@@ -89,10 +89,12 @@ class Main:
 
 	#Translate word with translator-class
 	def translate(self, event, to):
+		text = self.input.get_text().rstrip().lstrip()
+		self.input.set_text(text)
 		if to == "1":
-			self.Translator.translate(self.Settings.config[1], self.Settings.config[0], self.input.get_text())
+			self.Translator.translate(self.Settings.config[1], self.Settings.config[0], text)
 		elif to == "2":
-			self.Translator.translate(self.Settings.config[0], self.Settings.config[1], self.input.get_text())
+			self.Translator.translate(self.Settings.config[0], self.Settings.config[1], text)
 
 	#Shut down application
 	def quit(self, ignore1, ignore2):
@@ -111,9 +113,9 @@ class About:
 		dialog.set_logo_icon_name("sanakirja.org")
 		dialog.set_authors(("Olli Laasonen [admin@laasonen.net]",""))
 		dialog.set_documenters(("Olli Laasonen [admin@laasonen.net]",""))
-		dialog.set_artists(("Eugen Buzuk [eugen.buzuk@gmail.com]","Salvador Lopez [simiographics@yahoo.com]"))
+		dialog.set_artists(("Eugen Buzuk [eugen.buzuk@gmail.com]","Salvador Lopez [simiographics@yahoo.com]", "Olli Laasonen [admin@laasonen.net]"))
 		dialog.set_comments("A Sanakirja.org dictionary client.")
-		dialog.set_version("0.4.0")
+		dialog.set_version("0.4.1")
 		dialog.set_license("This program is free software; you can redistribute it and/or\nmodify it under the terms of the GNU General Public License\nas published by the Free Software Foundation; either version 2\nof the License, or (at your option) any later version.")
 		dialog.set_copyright("(c) Olli Laasonen")
 		dialog.set_website("http://laasonen.net/")
